moya.auth

# Moya Authentication

moya.auth is a library for Moya web development framework

URL
  http://moyaproject.com
Long Name
  moya.auth
Author Name
  Will McGugan
Author URL
  http://www.willmcgugan.com
Organization
  Moya Project

## Documentation

1. Introduction
2. Customizing User Models
   - The first section
     - A sub-section
       - A sub sub section
     - Another sub section
3. Commands
4. Test

## Tags

Moya Authentication defines the following tags:

- <getpermissions>
- <getuser>
- <login>
- <logout>
- <newuser>

## Commands

Moya Authentication defines the following command line tools:

- `cmd.addperm`
- `cmd.adduser`
- `cmd.finduser`
- `cmd.groupadd`
- `cmd.groupremove`
- `cmd.init`
- `cmd.listgroups`
- `cmd.listperms`
- `cmd.listusers`
- `cmd.newgroup`
- `cmd.newperm`
- `cmd.removeperm`
- `cmd.test`
- `cmd.testusers`